
## Read and attach the data
factorial_data <- read.table("factorial.txt", header=T)
attach(factorial_data)

## Use factor() to flag density as a categorical variable
cat_density <- factor(density)

### PART I. Two-way ANOVA: Both Factors Are Fixed ###
model <- lm(number ~ season + cat_density + season:cat_density)
anova(model)

## Get mean squares (MS) from the ANOVA
results <- anova(model)
MS_A <- results[1,3]
MS_B <- results[2,3]
MS_AB <- results[3,3]
MS_resid <- results[4,3]

## Get degrees of freedom (df) from the ANOVA
df_A <- results[1,1]
df_B <- results[2,1]
df_AB <- results[3,1]
df_resid <- results[4,1]

## Calculate F-ratio & P-value for fixed Factor A
F_ratio_A <- MS_A/MS_resid
p_A <- pf(F_ratio_A, df_A, df_resid, lower.tail=F)

## Calculate F-ratio & P-value for fixed Factor B
F_ratio_B <- MS_B/MS_resid
p_B <- pf(F_ratio_B, df_B, df_resid, lower.tail=F)

## Calculate F-ratio & P-value for Interaction (AxB)
F_ratio_AB <- MS_AB/MS_resid
p_AB <- pf(F_ratio_AB, df_AB, df_resid, lower.tail=F)


### PART II. Two-way ANOVA: Factor A is fixed, Factor B is random ###

## Calculate F-ratio & P-value for Factor A as MS_A/MS_AB
F_ratio_A <- MS_A/MS_AB
p_A <- pf(F_ratio_A, df_A, df_AB, lower.tail=F)

## NOTE: the F-ratios for Factor B and AxB do not change in this model


### PART III. Two-way ANOVA: Factor A and Factor B are random ###

## NOTE: here, the F-ratio for Factor A is the same as in Part II.

## Calculate F-ratio & P-value for Factor B as MS_B/MS_AB
F_ratio_B <- MS_B/MS_AB
p_B <- pf(F_ratio_B, df_B, df_AB, lower.tail=F)

## Detach the data
detach(factorial_data)